@@ -81,6 +81,7 @@
 #' \item{seTE}{Standard error of treatment estimate.}
 #' \item{seTE.adj}{Standard error of treatment estimate, adjusted for
 #'   multi-arm studies.}
+#' \item{design}{Design of study providing pairwise comparison.}
 #' \item{event1}{Number of events in first treatment group.}
 #' \item{event2}{Number of events in second treatment group.}
 #' \item{n1}{Number of observations in first treatment group.}
@@ -118,7 +119,7 @@
 #'   \emph{m} of upper confidence interval limits for the consistent
 #'   treatment effects estimated by network meta-analysis (fixed
 #'   and random effects model).}
-#' \item{zval.nma.fixed, zval.nma.random}{A vector of length \emph{m}
+#' \item{statistic.nma.fixed, statistic.nma.random}{A vector of length \emph{m}
 #'   of z-values for test of treatment effect for individual
 #'   comparisons (fixed and random effects model).}
 #' \item{pval.nma.fixed, pval.nma.random}{A vector of length \emph{m}
@@ -138,10 +139,10 @@
 #'   \emph{m} of upper confidence interval limits for consistent
 #'   treatment effects estimated by the additive (fixed and random
 #'   effects) model.}
-#' \item{zval.cnma.fixed, zval.cnma.random}{A vector of length
+#' \item{statistic.cnma.fixed, statistic.cnma.random}{A vector of length
 #'   \emph{m} of z-values for the test of an overall effect estimated
 #'   by the additive (fixed and random effects) model.}
-#' \item{pval.cnma.fixed, zval.cnma.random}{A vector of length
+#' \item{pval.cnma.fixed, pval.cnma.random}{A vector of length
 #'   \emph{m} of p-values for the test of an overall effect estimated
 #'   by the additive (fixed and random effects) model.}
 #' \item{TE.fixed, TE.random}{\emph{n}x\emph{n} matrix with overall
@@ -154,7 +155,7 @@
 #'   upper.random}{\emph{n}x\emph{n} matrices with lower and upper
 #'   confidence interval limits estimated by the additive (fixed and
 #'   random effects) model.}
-#' \item{zval.fixed, pval.fixed, zval.random,
+#' \item{statistic.fixed, pval.fixed, statistic.random,
 #'   pval.random}{\emph{n}x\emph{n} matrices with z-values and
 #'   p-values for test of overall effect estimated by the additive
 #'   (fixed and random effects) model.}
@@ -168,7 +169,7 @@
 #' \item{upper.Comp.fixed, upper.Comp.random}{A vector with upper
 #'   confidence limits for components (fixed and random effects
 #'   model).}
-#' \item{zval.Comp.fixed, zval.Comp.random}{A vector with z-values for
+#' \item{statistic.Comp.fixed, statistic.Comp.random}{A vector with z-values for
 #'   the overall effect of components (fixed and random effects
 #'   model).}
 #' \item{pval.Comp.fixed, pval.Comp.random}{A vector with p-values for
@@ -184,7 +185,7 @@
 #' \item{upper.Comb.fixed, upper.Comb.random}{A vector with upper
 #'   confidence limits for combinations (fixed and random effects
 #'   model).}
-#' \item{zval.Comb.fixed, zval.Comb.random}{A vector with z-values for
+#' \item{statistic.Comb.fixed, statistic.Comb.random}{A vector with z-values for
 #'   the overall effect of combinations (fixed and random effects
 #'   model).}
 #' \item{pval.Comb.fixed, pval.Comb.random}{A vector with p-values for
@@ -335,13 +336,15 @@ netcomb <- function(x,
   ##
   meta:::chkclass(x, "netmeta")
   ##
+  x <- upgradenetmeta(x)
+  ##
   meta:::chkchar(sep.comps, nchar = 1)
   ##
   meta:::chklogical(comb.fixed)
   meta:::chklogical(comb.random)
   ##
   if (!is.null(tau.preset))
-    meta:::chknumeric(tau.preset, min = 0, single = TRUE)
+    meta:::chknumeric(tau.preset, min = 0, length = 1)
   
   
   ##
@@ -503,6 +506,8 @@ netcomb <- function(x,
               seTE = x$seTE,
               seTE.adj = x$seTE.adj,
               ##
+              design = x$design,
+              ##
               event1 = x$event1,
               event2 = x$event2,
               n1 = x$n1,
@@ -536,70 +541,70 @@ netcomb <- function(x,
               seTE.nma.fixed = x$seTE.nma.fixed,
               lower.nma.fixed = x$lower.nma.fixed,
               upper.nma.fixed = x$upper.nma.fixed,
-              zval.nma.fixed = x$zval.nma.fixed,
+              statistic.nma.fixed = x$statistic.nma.fixed,
               pval.nma.fixed = x$pval.nma.fixed,
               ##
               TE.cnma.fixed = res.f$comparisons$TE,
               seTE.cnma.fixed = res.f$comparisons$seTE,
               lower.cnma.fixed = res.f$comparisons$lower,
               upper.cnma.fixed = res.f$comparisons$upper,
-              zval.cnma.fixed = res.f$comparisons$z,
+              statistic.cnma.fixed = res.f$comparisons$statistic,
               pval.cnma.fixed = res.f$comparisons$p,
               ##
               TE.fixed = res.f$all.comparisons$TE,
               seTE.fixed = res.f$all.comparisons$seTE,
               lower.fixed = res.f$all.comparisons$lower,
               upper.fixed = res.f$all.comparisons$upper,
-              zval.fixed = res.f$all.comparisons$z,
+              statistic.fixed = res.f$all.comparisons$statistic,
               pval.fixed = res.f$all.comparisons$p,
               ##
               TE.nma.random = x$TE.nma.random,
               seTE.nma.random = x$seTE.nma.random,
               lower.nma.random = x$lower.nma.random,
               upper.nma.random = x$upper.nma.random,
-              zval.nma.random = x$zval.nma.random,
+              statistic.nma.random = x$statistic.nma.random,
               pval.nma.random = x$pval.nma.random,
               ##
               TE.cnma.random = res.r$comparisons$TE,
               seTE.cnma.random = res.r$comparisons$seTE,
               lower.cnma.random = res.r$comparisons$lower,
               upper.cnma.random = res.r$comparisons$upper,
-              zval.cnma.random = res.r$comparisons$z,
+              statistic.cnma.random = res.r$comparisons$statistic,
               pval.cnma.random = res.r$comparisons$p,
               ##
               TE.random = res.r$all.comparisons$TE,
               seTE.random = res.r$all.comparisons$seTE,
               lower.random = res.r$all.comparisons$lower,
               upper.random = res.r$all.comparisons$upper,
-              zval.random = res.r$all.comparisons$z,
+              statistic.random = res.r$all.comparisons$statistic,
               pval.random = res.r$all.comparisons$p,
               ##
               Comp.fixed = unname(res.f$components$TE),
               seComp.fixed = unname(res.f$components$seTE),
               lower.Comp.fixed = unname(res.f$components$lower),
               upper.Comp.fixed = unname(res.f$components$upper),
-              zval.Comp.fixed = unname(res.f$components$z),
+              statistic.Comp.fixed = unname(res.f$components$statistic),
               pval.Comp.fixed = unname(res.f$components$p),
               ##
               Comp.random = unname(res.r$components$TE),
               seComp.random = unname(res.r$components$seTE),
               lower.Comp.random = unname(res.r$components$lower),
               upper.Comp.random = unname(res.r$components$upper),
-              zval.Comp.random = unname(res.r$components$z),
+              statistic.Comp.random = unname(res.r$components$statistic),
               pval.Comp.random = unname(res.r$components$p),
               ##
               Comb.fixed = unname(res.f$combinations$TE),
               seComb.fixed = unname(res.f$combinations$seTE),
               lower.Comb.fixed = unname(res.f$combinations$lower),
               upper.Comb.fixed = unname(res.f$combinations$upper),
-              zval.Comb.fixed = unname(res.f$combinations$z),
+              statistic.Comb.fixed = unname(res.f$combinations$statistic),
               pval.Comb.fixed = unname(res.f$combinations$p),
               ##
               Comb.random = unname(res.r$combinations$TE),
               seComb.random = unname(res.r$combinations$seTE),
               lower.Comb.random = unname(res.r$combinations$lower),
               upper.Comb.random = unname(res.r$combinations$upper),
-              zval.Comb.random = unname(res.r$combinations$z),
+              statistic.Comb.random = unname(res.r$combinations$statistic),
               pval.Comb.random = unname(res.r$combinations$p),
               ##
               Q.additive = Q.additive,
@@ -624,6 +629,9 @@ netcomb <- function(x,
               n.matrix = x$n.matrix,
               events.matrix = x$events.matrix,
               ##
+              Cov.fixed = x$Cov.fixed,
+              Cov.random = x$Cov.random,
+              ##
               sm = x$sm,
               method = "Inverse",
               level = x$level,
